*************************************************************
****Chapter 12: Nominal responses and discrete choice  ******
*************************************************************


*** 12.2 Single-level models for nominal responses


** 12.2.1 Multinomial logit models

use http://www.stata-press.com/data/mlmus3/travel1, clear

list traveler alt Hinc Psize in 1/10, noobs clean

mlogit alt Hinc Psize, baseoutcome(4)

label define modelabels 1 "Air" 2 "Train" 3 "Bus" 4 "Car"
label values alt modelabels

mlogit alt Hinc Psize, baseoutcome(4) rrr


** 12.2.2 Conditional logit models

use http://www.stata-press.com/data/mlmus3/travel2, clear

list traveler alt Choice GC Ttime in 1/8, sepby(traveler) noobs

clogit Choice GC Ttime, group(traveler) 

clogit Choice GC Ttime, group(traveler) or

tabulate alt, gen(a)

rename a1 air
rename a2 train
rename a3 bus
rename a4 car

generate airXhinc = air*Hinc
generate trainXhinc = train*Hinc
generate busXhinc = bus*Hinc

generate airXpsize = air*Psize
generate trainXpsize = train*Psize
generate busXpsize = bus*Psize

/*

foreach var of varlist Hinc Psize {
	generate airX`var' = air*`var' 
	generate trainX`var' = train*`var'
	generate busX`var' = bus*`var'
}
*/

clogit Choice airXhinc airXpsize air trainXhinc trainXpsize train ///
  busXhinc busXpsize bus GC Ttime, group(traveler)

asclogit Choice GC Ttime, case(traveler) casevar(Hinc Psize) ///
  alternatives(alt) basealternative(4)


*** 12.5 Does marketing affect choice of yogurt?

use http://www.stata-press.com/data/mlmus3/yogurt, clear

drop if brand==3
egen sum = total(choice), by(house occ)
drop if sum==0

recode brand(4=3)
label define b 1 "Yoplait" 2 "Dannon" 3 "WeightW", modify
label values brand b

egen set = group(house occ)

generate pricec = price*100
drop price

sort house occ
list if house==24, sepby(occ) noobs 


*** 12.6 Single-level conditional logit models

** 12.6.1 Conditional logit model with alternative-specific intercepts

tabulate brand, generate(br)
rename br1 Yoplait
rename br2 Dannon
rename br3 WeightW

clogit choice Yoplait WeightW feature pricec, group(set) vce(cluster house)

gllamm brand Yoplait WeightW feature pricec, i(house) link(mlogit) ///
   expanded(set choice o) noconstant cluster(house) robust init
   
estimates store condlogit

gllamm, eform


*** 12.7 Multilevel conditional logit models

** 12.7.1 Preference heterogeneity: Brand-specific random intercepts

eq Yo: Yoplait
eq We: WeightW
gllamm brand Yoplait WeightW feature pricec,          ///
   i(house) link(mlogit) exp(set choice o) noconstant ///
   nrf(2) eqs(Yo We) adapt 
estimates store rint

lrtest rint condlogit

gllamm, eform


** 12.7.2 Response heterogeneity: Marketing variables with random coefficients

eq pr: pricec
eq fea: feature
gllamm brand Yoplait WeightW feature pricec,          ///
   i(house) link(mlogit) exp(set choice o) noconstant ///
   nrf(2) eqs(pr fea) adapt
estimates store rcoeff

lrtest rcoeff condlogit

gllamm, eform

display exp(.792219 - 1.96*sqrt(.49884762))
display exp(.792219 + 1.96*sqrt(.49884762))

display exp(-.5337412 - 1.96*sqrt(1.1857948))
display exp(-.5337412 + 1.96*sqrt(1.1857948))


** 12.7.3 Preference and response heterogeneity

* Estimation using gllamm

eq Yo: Yoplait
eq We: WeightW
eq pr: pricec
eq fea: feature

gllamm brand Yoplait WeightW feature pricec, i(house) link(mlogit) exp(set choice o) noconstant ///
   eqs(Yo We pr fea) nrf(4) adapt 

gllamm, eform

* Estimation using mixlogit

ssc install mixlogit, replace

mixlogit choice, /// 
 group(set) id(house) rand(Yoplait WeightW feature pricec) corr
mixlcov

* 10000 Halton draws
mixlogit choice, /// 
 group(set) id(house) rand(Yoplait WeightW feature pricec) corr nrep(10000)
mixlcov


** 12.8 Prediction of random effects and response probabilities 

estimates restore rcoeff

gllapred eb, u 
generate eb_pricec = ebm1 + _b[pricec]
generate eb_feature = ebm2 + _b[feature]

egen pickone = tag(house)
twoway scatter eb_pricec eb_feature if pickone==1, mlabel(house) ///
   xtitle(EB prediction of feature coefficient) ///
   ytitle(EB prediction of price coefficient) 

save temp, replace

drop _all
set obs 40
generate pricec =  _n*.5
generate set = 3000 + _n
expand 3
by set, sort: generate brand=_n
generate yopprice = pricec
replace pricec = 8 if brand>1
generate feature = 0
tabulate brand, generate(br)
rename br1 Yoplait
rename br2 Dannon
rename br3 WeightW
generate choice = Dannon
expand 6
by set brand, sort: generate house=_n
recode house 1=33 2=15 3=7 4=48 5=6 6=55
replace brand = .
append using temp

generate preddata = brand ==.

gllapred probs, mu fsample
egen select = anymatch(house), values(33 15 7 48 6 55)

twoway (line probs yopprice if Yoplait==1, sort) ///
  (line probs yopprice if WeightW==1, sort lpatt(longdash)) ///
  (line probs yopprice if Dannon==1, sort lpatt(shortdash)) ///
  if feature==0&select==1&preddata==1, ///
  by(house) legend(order(1 "Yoplait" 2 "WeightW" 3 "Dannon") rows(1)) ///
  xtitle(Price of Yoplait in cents/oz) ytitle(Probability of purchase)
  



   



