*******************************************************************
****Chapter 16: Models with nested and crossed random effects *****
*******************************************************************


*** 16.2 Did the Guatemalan immunization campaign work?

use http://www.stata-press.com/data/mlmus3/guatemala, clear


*** 16.4 Estimation of three-level random-intercept logistic regression models

** 16.4.1 Using gllamm 

gllamm immun kid2p indNoSpa indSpa  momEdPri momEdSec husEdPri husEdSec  ///
   husEdDK rural pcInd81, family(binomial) link(logit) i(mom cluster) ///
   nip(5)

matrix a=e(b)
gllamm immun kid2p indNoSpa indSpa  momEdPri momEdSec husEdPri husEdSec  ///
   husEdDK rural pcInd81, family(binomial) link(logit) i(mom cluster) ///
   from(a) adapt
estimates store glri8
gllamm, eform

display 1.0274/(1.0274+5.1872+_pi^2/3)
display (1.0274+5.1872)/(1.0274+5.1872+_pi^2/3)

display exp(sqrt(2*(1.0274+5.1872))*invnorm(3/4))
display exp(sqrt(2*(5.1872))*invnorm(3/4))


** 16.4.2 Using xtmelogit 
* Laplace 
xtmelogit immun kid2p indNoSpa indSpa momEdPri momEdSec husEdPri husEdSec ///
   husEdDK rural pcInd81 || cluster: || mom:, intpoints(1)

* Adaptive quadrature
matrix a = e(b)
xtmelogit immun kid2p indNoSpa indSpa momEdPri momEdSec husEdPri husEdSec ///
   husEdDK rural pcInd81 || cluster: || mom:, intpoints(5) ///
   from(a) refineopts(iterate(0))

matrix a = e(b)
xtmelogit immun kid2p indNoSpa indSpa momEdPri momEdSec husEdPri husEdSec ///
   husEdDK rural pcInd81 || cluster: || mom:, intpoints(8) ///
   from(a) refineopts(iterate(0))

display chi2tail(1,151.27)/2 + chi2tail(2,151.27)/4


*** 16.6 Estimation of three-level random-coefficient logistic regression model

** 16.6.1 Using gllamm 
* Three-level random intercept model
estimates restore glri8
matrix a=e(b)
gllamm immun kid2p rural pcInd81, family(binomial) link(logit) ///
   i(mom cluster) from(a) skip adapt eform
estimates store glri0

* Three-level random coefficient model
generate cons=1
eq inter: cons
eq slope: kid2p
matrix a = e(b)
matrix a = (a,.2,0)
gllamm immun kid2p rural pcInd81, family(binomial) link(logit) i(mom cluster) ///
   nrf(1 2) eqs(inter inter slope) nip(8 4 4) from(a) copy adapt eform
estimates store glrc

lrtest glrc glri0

** 16.6.2 Using xtmelogit 

xtmelogit immun kid2p rural pcInd81 || cluster: kid2p, covariance(unstructured) || mom:, ///
   intpoints(4 8) or
estimates store xtrc


*** 16.7 Prediction of random effects

** 16.7.1 Empirical Bayes prediction

estimates restore glrc
gllapred zeta, u
sort cluster mom
list cluster mom zetam1 zetam2 zetam3 in 1/9, sepby(mom) noobs

egen pick_comm = tag(cluster)
twoway scatter zetam3 zetam2 if pick_com==1, xtitle(Intercept) ytitle(Slope)

** 16.7.2 Empirical Bayes modal prediction

estimates restore xtrc
predict comms commi mother, reffects

sort cluster mom
list cluster mom mother commi comms in 1/9, sepby(mom) noobs


*** 16.8 Different kinds of predicted probabilities

** 16.8.1 Predicted population-averaged or marginal probabilities: New clusters

estimates restore glrc
gllapred margp, mu marginal

** 16.8.2 Predicted median or conditional probabilities

generate z1 = 0
generate z2 = 0
generate z3 = 0
gllapred condp, mu us(z)

label define r 0 "Urban" 1 "Rural"
label values rural r
twoway (line condp pcInd81 if kid2p==0, lpatt(solid) sort) ///
       (line condp pcInd81 if kid2p==1, lpatt(solid) sort) ///
       (line margp pcInd81 if kid2p==0, lpatt(dash) sort) ///
       (line margp pcInd81 if kid2p==1, lpatt(dash) sort), ///
        by(rural) legend(order(1 "Conditional" 3 "Marginal")) ///
        xtitle(Perentage Indigenous) ytitle(Probability)

** 16.8.3 Predicted posterior mean probabilities: Existing clusters

gllapred postp, mu
sort cluster mom
list cluster mom kid2p zetam1 zetam2 zetam3 postp in 1/9, sepby(mom) noobs


*** 16.9 Do salamanders from different populations mate successfully?

use http://www.stata-press.com/data/mlmus3/salamander, clear

table female male if group==1, contents(mean y)


*** 16.10 Crossed random effects logistic regression

generate m = male - (group-1)*10
generate f = female - (group-1)*10

egen pickmale = tag(male)
sort m group
list group male m if pickmale==1&m<3, sepby(m) noobs

generate ww = wsf*wsm

xtmelogit y wsm wsf ww || group: R.m || f:, laplace

matrix a = e(b)
xtmelogit y wsm wsf ww || group: R.m || f:, intpoints(2) from(a) ///
  refineopts(iterate(0))

matrix a=e(b)
xtmelogit y wsm wsf ww || group: R.m || f:, intpoints(3) from(a) ///
  refineopts(iterate(0))

display chi2tail(1,30.15)/2 + chi2tail(2,30.15)/4

lincom _cons, or
lincom _cons + wsf, or
lincom _cons + wsm, or
lincom _cons + wsm + wsf + ww, or

display exp(sqrt(2*(1.10^2+1.16^2))*invnormal(3/4))


