*******************************************
****Chapter 9: Crossed random effects*****
*******************************************


*** 9.2 How does investment depend on expected profit and capital stock?

use http://www.stata-press.com/data/mlmus3/grunfeld, clear

*** 9.3 A two-way error-components model

** 9.3.3 Estimation using xtmixed

xtmixed I F C || _all: R.fn || yr:, mle  

* xtmixed I F C || _all: R.yr || fn:, mle  

xtmixed I F C || _all: R.fn || yr:, reml

matrix list e(b)
display exp(2*[lns1_1_1]_cons)/(exp(2*[lns1_1_1]_cons) + exp(2*[lns2_1_1]_cons) ///
 + exp(2*[lnsig_e]_cons))

** 9.3.4 Prediction
predict firm year, reffects
sort fn yr
list fn firmname yr firm year if yr<1938&fn<5, sepby(fn) noobs

generate reffpart = firm + year
twoway (line reffpart yr, connect(ascending))                                    ///
   (scatter reffpart yr if yr==1954, msymbol(none) mlabel(firmname) mlabpos(3)), ///
   xtitle(Year) ytitle(Predicted random effects of firm and year)                ///
   xscale(range(1935 1958)) legend(off)

twoway line year yr if fn==1, xtitle(Year) ///
  ytitle(Predicted random effect for year)


*** 9.4 How much do primary and secondary schools...

use http://www.stata-press.com/data/mlmus3/fife, clear

*** 9.5 Data structure

egen pick_comb= tag(pid sid)
egen numsid = sum(pick_comb), by(pid)
sort pid sid
list pid sid numsid if pick_comb & pid<10, sepby(pid) noobs

egen pick_pid = tag(pid)
tabulate numsid if pick_pid

egen numpid = total(pick_comb), by(sid)
egen pick_sid = tag(sid)
tabulate numpid if pick_sid


*** 9.6 Additive crossed random-effects model

** 9.6.2 Estimation using xtmixed

xtmixed attain || _all: R.sid || pid:, mle
estimates store additive


*** 9.7 Crossed random-effects model with random interaction

** 9.7.3 Estimation using xtmixed

xtmixed attain || _all: R.sid || pid:, mle
egen comb = group(sid pid)

xtmixed attain || _all: R.sid || pid: || sid:, mle
estimates store interaction

** 9.7.4 Testing variance components

display 3/8*chi2tail(1,279.29) + 3/8*chi2tail(2,279.29) + 1/8*chi2tail(3,279.29) 

lrtest additive interaction

display 1/2*chi2tail(1,278.13) + 1/4*chi2tail(2,278.13)

quietly xtmixed attain || sid:, mle
estimates store secondary
lrtest secondary additive

** 9.7.5 Some diagnostics

estimates restore additive

predict secondary primary, reffects

qnorm secondary if pick_sid, xtitle(Quantiles of normal distribution) ///
  ytitle(Quantiles of empirical Bayes predictions)
 
qnorm primary if pick_pid, xtitle(Quantiles of normal distribution) ///
  ytitle(Quantiles of empirical Bayes predictions)


*** 9.8 A trick requiring fewer random effects

ssc install supclust, replace

supclust pid sid, generate(region)

egen num = count(attain), by(sid pid)
drop if num<3
drop region
supclust sid pid, gen(region)

by region sid, sort: generate f = _n==1
by region: generate sec = sum(f)
table sec

xtmixed attain || region: R.sec || pid:, mle


